@@ -1,6 +1,6 @@
 __all__ = ['itu453', 'itu530', 'itu618', 'itu676', 'itu835', 'itu836',
            'itu837', 'itu838', 'itu839', 'itu840', 'itu1144', 'itu1510',
-           'itu1511', 'itu1853']
+           'itu1511', 'itu1623', 'itu1853']
 
 import itur.models.itu453
 import itur.models.itu530
@@ -14,4 +14,5 @@ import itur.models.itu840
 import itur.models.itu1144
 import itur.models.itu1510
 import itur.models.itu1511
+import itur.models.itu1623
 import itur.models.itu1853
